@@ -103,7 +103,7 @@ class SliceUpload(object):
         for offset in self.offsetlist:
             for result in results:
                 if offset == result['offset'] and result['code'] != 200:
-                    fail_list.append(result)
+                    fail_list.append(result['offset'])
         return fail_list
 
     def blockStatus(self, results):
@@ -259,7 +259,7 @@ class SliceUpload(object):
         if self.need_retry(code):
            error('Sorry, the make_file error, %d, %s' % (code, text))
            self.blockStatus = []
-           self.upload_progress_recorder.delete_upload_record(self.key)
         else:
            debug('Make_file suc! sliceupload complet!')
+        self.upload_progress_recorder.delete_upload_record(self.key)
         return code, text
